use std::{fs, io::ErrorKind, num::ParseIntError, path::PathBuf};

use rand::distributions::{Alphanumeric, DistString as _};

/// Decode hexadecimal to bytes (inspired from
/// <https://gist.github.com/rust-play/e241493d100ecaadac3c99f37d0f766f>).
pub fn hex_decode(s: &str) -> Result<Vec<u8>, ParseIntError> {
    (0..s.len())
        .step_by(2)
        .map(|i| u8::from_str_radix(&s[i..i + 2], 16))
        .collect()
}

/// Generate a random alphanumeric token (taken from <https://stackoverflow.com/a/72977937>).
pub fn random_token(n: usize) -> String {
    Alphanumeric.sample_string(&mut rand::thread_rng(), n)
}

/// Remove a file from disk, and log a warning on error.
pub fn remove_file(path: &PathBuf) {
    if let Err(error) = fs::remove_file(path) {
        if error.kind() != ErrorKind::NotFound {
            warn!("couldn't remove file {:?} : {}", path, error);
        }
    }
}
